==> server_base-0.9.0-sources.jar: sila2/org/silastandard/core/authorizationproviderservice/v1/AuthorizationProviderServiceGrpc.java <==
package sila2.org.silastandard.core.authorizationproviderservice.v1;

import static io.grpc.MethodDescriptor.generateFullMethodName;

/**
 */
@javax.annotation.Generated(
    value = "by gRPC proto compiler (version 1.50.2)",
    comments = "Source: AuthorizationProviderService.proto")
@io.grpc.stub.annotations.GrpcGenerated
public final class AuthorizationProviderServiceGrpc {

  private AuthorizationProviderServiceGrpc() {}

  public static final String SERVICE_NAME = "sila2.org.silastandard.core.authorizationproviderservice.v1.AuthorizationProviderService";

  // Static method descriptors that strictly reflect the proto.
  private static volatile io.grpc.MethodDescriptor<sila2.org.silastandard.core.authorizationproviderservice.v1.AuthorizationProviderServiceOuterClass.Verify_Parameters,
      sila2.org.silastandard.core.authorizationproviderservice.v1.AuthorizationProviderServiceOuterClass.Verify_Responses> getVerifyMethod;

  @io.grpc.stub.annotations.RpcMethod(
      fullMethodName = SERVICE_NAME + '/' + "Verify",
      requestType = sila2.org.silastandard.core.authorizationproviderservice.v1.AuthorizationProviderServiceOuterClass.Verify_Parameters.class,
      responseType = sila2.org.silastandard.core.authorizationproviderservice.v1.AuthorizationProviderServiceOuterClass.Verify_Responses.class,
      methodType = io.grpc.MethodDescriptor.MethodType.UNARY)
  public static io.grpc.MethodDescriptor<sila2.org.silastandard.core.authorizationproviderservice.v1.AuthorizationProviderServiceOuterClass.Verify_Parameters,
      sila2.org.silastandard.core.authorizationproviderservice.v1.AuthorizationProviderServiceOuterClass.Verify_Responses> getVerifyMethod() {
    io.grpc.MethodDescriptor<sila2.org.silastandard.core.authorizationproviderservice.v1.AuthorizationProviderServiceOuterClass.Verify_Parameters, sila2.org.silastandard.core.authorizationproviderservice.v1.AuthorizationProviderServiceOuterClass.Verify_Responses> getVerifyMethod;
    if ((getVerifyMethod = AuthorizationProviderServiceGrpc.getVerifyMethod) == null) {
      synchronized (AuthorizationProviderServiceGrpc.class) {
        if ((getVerifyMethod = AuthorizationProviderServiceGrpc.getVerifyMethod) == null) {
          AuthorizationProviderServiceGrpc.getVerifyMethod = getVerifyMethod =
              io.grpc.MethodDescriptor.<sila2.org.silastandard.core.authorizationproviderservice.v1.AuthorizationProviderServiceOuterClass.Verify_Parameters, sila2.org.silastandard.core.authorizationproviderservice.v1.AuthorizationProviderServiceOuterClass.Verify_Responses>newBuilder()
              .setType(io.grpc.MethodDescriptor.MethodType.UNARY)
              .setFullMethodName(generateFullMethodName(SERVICE_NAME, "Verify"))
              .setSampledToLocalTracing(true)
              .setRequestMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  sila2.org.silastandard.core.authorizationproviderservice.v1.AuthorizationProviderServiceOuterClass.Verify_Parameters.getDefaultInstance()))
              .setResponseMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  sila2.org.silastandard.core.authorizationproviderservice.v1.AuthorizationProviderServiceOuterClass.Verify_Responses.getDefaultInstance()))
              .setSchemaDescriptor(new AuthorizationProviderServiceMethodDescriptorSupplier("Verify"))
              .build();
        }
      }
    }
    return getVerifyMethod;
  }

  /**
   * Creates a new async stub that supports all call types for the service
   */
  public static AuthorizationProviderServiceStub newStub(io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<AuthorizationProviderServiceStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<AuthorizationProviderServiceStub>() {
        @java.lang.Override
        public AuthorizationProviderServiceStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new AuthorizationProviderServiceStub(channel, callOptions);
        }
      };
    return AuthorizationProviderServiceStub.newStub(factory, channel);
  }

  /**
   * Creates a new blocking-style stub that supports unary and streaming output calls on the service
   */
  public static AuthorizationProviderServiceBlockingStub newBlockingStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<AuthorizationProviderServiceBlockingStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<AuthorizationProviderServiceBlockingStub>() {
        @java.lang.Override
        public AuthorizationProviderServiceBlockingStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new AuthorizationProviderServiceBlockingStub(channel, callOptions);
        }
      };
    return AuthorizationProviderServiceBlockingStub.newStub(factory, channel);
  }

  /**
   * Creates a new ListenableFuture-style stub that supports unary calls on the service
   */
  public static AuthorizationProviderServiceFutureStub newFutureStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<AuthorizationProviderServiceFutureStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<AuthorizationProviderServiceFutureStub>() {
        @java.lang.Override
        public AuthorizationProviderServiceFutureStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new AuthorizationProviderServiceFutureStub(channel, callOptions);
        }
      };
    return AuthorizationProviderServiceFutureStub.newStub(factory, channel);
  }

  /**
   */
  public static abstract class AuthorizationProviderServiceImplBase implements io.grpc.BindableService {

    /**
     */
    public void verify(sila2.org.silastandard.core.authorizationproviderservice.v1.AuthorizationProviderServiceOuterClass.Verify_Parameters request,
        io.grpc.stub.StreamObserver<sila2.org.silastandard.core.authorizationproviderservice.v1.AuthorizationProviderServiceOuterClass.Verify_Responses> responseObserver) {
      io.grpc.stub.ServerCalls.asyncUnimplementedUnaryCall(getVerifyMethod(), responseObserver);
    }

    @java.lang.Override public final io.grpc.ServerServiceDefinition bindService() {
      return io.grpc.ServerServiceDefinition.builder(getServiceDescriptor())
          .addMethod(
            getVerifyMethod(),
            io.grpc.stub.ServerCalls.asyncUnaryCall(
              new MethodHandlers<
                sila2.org.silastandard.core.authorizationproviderservice.v1.AuthorizationProviderServiceOuterClass.Verify_Parameters,
                sila2.org.silastandard.core.authorizationproviderservice.v1.AuthorizationProviderServiceOuterClass.Verify_Responses>(
                  this, METHODID_VERIFY)))
          .build();
    }
  }

  /**
   */
  public static final class AuthorizationProviderServiceStub extends io.grpc.stub.AbstractAsyncStub<AuthorizationProviderServiceStub> {
    private AuthorizationProviderServiceStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected AuthorizationProviderServiceStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new AuthorizationProviderServiceStub(channel, callOptions);
    }

    /**
     */
    public void verify(sila2.org.silastandard.core.authorizationproviderservice.v1.AuthorizationProviderServiceOuterClass.Verify_Parameters request,
        io.grpc.stub.StreamObserver<sila2.org.silastandard.core.authorizationproviderservice.v1.AuthorizationProviderServiceOuterClass.Verify_Responses> responseObserver) {
      io.grpc.stub.ClientCalls.asyncUnaryCall(
          getChannel().newCall(getVerifyMethod(), getCallOptions()), request, responseObserver);
    }
  }

  /**
   */
  public static final class AuthorizationProviderServiceBlockingStub extends io.grpc.stub.AbstractBlockingStub<AuthorizationProviderServiceBlockingStub> {
    private AuthorizationProviderServiceBlockingStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected AuthorizationProviderServiceBlockingStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new AuthorizationProviderServiceBlockingStub(channel, callOptions);
    }

    /**
     */
    public sila2.org.silastandard.core.authorizationproviderservice.v1.AuthorizationProviderServiceOuterClass.Verify_Responses verify(sila2.org.silastandard.core.authorizationproviderservice.v1.AuthorizationProviderServiceOuterClass.Verify_Parameters request) {
      return io.grpc.stub.ClientCalls.blockingUnaryCall(
          getChannel(), getVerifyMethod(), getCallOptions(), request);
    }
  }

  /**
   */
  public static final class AuthorizationProviderServiceFutureStub extends io.grpc.stub.AbstractFutureStub<AuthorizationProviderServiceFutureStub> {
    private AuthorizationProviderServiceFutureStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected AuthorizationProviderServiceFutureStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new AuthorizationProviderServiceFutureStub(channel, callOptions);
    }

    /**
     */
    public com.google.common.util.concurrent.ListenableFuture<sila2.org.silastandard.core.authorizationproviderservice.v1.AuthorizationProviderServiceOuterClass.Verify_Responses> verify(
        sila2.org.silastandard.core.authorizationproviderservice.v1.AuthorizationProviderServiceOuterClass.Verify_Parameters request) {
      return io.grpc.stub.ClientCalls.futureUnaryCall(
          getChannel().newCall(getVerifyMethod(), getCallOptions()), request);
    }
  }

  private static final int METHODID_VERIFY = 0;

  private static final class MethodHandlers<Req, Resp> implements
      io.grpc.stub.ServerCalls.UnaryMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ServerStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ClientStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.BidiStreamingMethod<Req, Resp> {
    private final AuthorizationProviderServiceImplBase serviceImpl;
    private final int methodId;

    MethodHandlers(AuthorizationProviderServiceImplBase serviceImpl, int methodId) {
      this.serviceImpl = serviceImpl;
      this.methodId = methodId;
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public void invoke(Req request, io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        case METHODID_VERIFY:
          serviceImpl.verify((sila2.org.silastandard.core.authorizationproviderservice.v1.AuthorizationProviderServiceOuterClass.Verify_Parameters) request,
              (io.grpc.stub.StreamObserver<sila2.org.silastandard.core.authorizationproviderservice.v1.AuthorizationProviderServiceOuterClass.Verify_Responses>) responseObserver);
          break;
        default:
          throw new AssertionError();
      }
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public io.grpc.stub.StreamObserver<Req> invoke(
        io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        default:
          throw new AssertionError();
      }
    }
  }

  private static abstract class AuthorizationProviderServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoFileDescriptorSupplier, io.grpc.protobuf.ProtoServiceDescriptorSupplier {
    AuthorizationProviderServiceBaseDescriptorSupplier() {}

    @java.lang.Override
    public com.google.protobuf.Descriptors.FileDescriptor getFileDescriptor() {
      return sila2.org.silastandard.core.authorizationproviderservice.v1.AuthorizationProviderServiceOuterClass.getDescriptor();
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.ServiceDescriptor getServiceDescriptor() {
      return getFileDescriptor().findServiceByName("AuthorizationProviderService");
    }
  }

  private static final class AuthorizationProviderServiceFileDescriptorSupplier
      extends AuthorizationProviderServiceBaseDescriptorSupplier {
    AuthorizationProviderServiceFileDescriptorSupplier() {}
  }

  private static final class AuthorizationProviderServiceMethodDescriptorSupplier
      extends AuthorizationProviderServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoMethodDescriptorSupplier {
    private final String methodName;

    AuthorizationProviderServiceMethodDescriptorSupplier(String methodName) {
      this.methodName = methodName;
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.MethodDescriptor getMethodDescriptor() {
      return getServiceDescriptor().findMethodByName(methodName);
    }
  }

  private static volatile io.grpc.ServiceDescriptor serviceDescriptor;

  public static io.grpc.ServiceDescriptor getServiceDescriptor() {
    io.grpc.ServiceDescriptor result = serviceDescriptor;
    if (result == null) {
      synchronized (AuthorizationProviderServiceGrpc.class) {
        result = serviceDescriptor;
        if (result == null) {
          serviceDescriptor = result = io.grpc.ServiceDescriptor.newBuilder(SERVICE_NAME)
              .setSchemaDescriptor(new AuthorizationProviderServiceFileDescriptorSupplier())
              .addMethod(getVerifyMethod())
              .build();
        }
      }
    }
    return result;
  }
}

==> server_base-0.12.0-sources.jar: sila2/org/silastandard/core/authorizationproviderservice/v1/AuthorizationProviderServiceGrpc.java <==
package sila2.org.silastandard.core.authorizationproviderservice.v1;

import static io.grpc.MethodDescriptor.generateFullMethodName;

/**
 */
@javax.annotation.Generated(
    value = "by gRPC proto compiler (version 1.50.2)",
    comments = "Source: sila2/org/silastandard/core/authorizationproviderservice/v1/AuthorizationProviderService.proto")
@io.grpc.stub.annotations.GrpcGenerated
public final class AuthorizationProviderServiceGrpc {

  private AuthorizationProviderServiceGrpc() {}

  public static final String SERVICE_NAME = "sila2.org.silastandard.core.authorizationproviderservice.v1.AuthorizationProviderService";

  // Static method descriptors that strictly reflect the proto.
  private static volatile io.grpc.MethodDescriptor<sila2.org.silastandard.core.authorizationproviderservice.v1.AuthorizationProviderServiceOuterClass.Verify_Parameters,
      sila2.org.silastandard.core.authorizationproviderservice.v1.AuthorizationProviderServiceOuterClass.Verify_Responses> getVerifyMethod;

  @io.grpc.stub.annotations.RpcMethod(
      fullMethodName = SERVICE_NAME + '/' + "Verify",
      requestType = sila2.org.silastandard.core.authorizationproviderservice.v1.AuthorizationProviderServiceOuterClass.Verify_Parameters.class,
      responseType = sila2.org.silastandard.core.authorizationproviderservice.v1.AuthorizationProviderServiceOuterClass.Verify_Responses.class,
      methodType = io.grpc.MethodDescriptor.MethodType.UNARY)
  public static io.grpc.MethodDescriptor<sila2.org.silastandard.core.authorizationproviderservice.v1.AuthorizationProviderServiceOuterClass.Verify_Parameters,
      sila2.org.silastandard.core.authorizationproviderservice.v1.AuthorizationProviderServiceOuterClass.Verify_Responses> getVerifyMethod() {
    io.grpc.MethodDescriptor<sila2.org.silastandard.core.authorizationproviderservice.v1.AuthorizationProviderServiceOuterClass.Verify_Parameters, sila2.org.silastandard.core.authorizationproviderservice.v1.AuthorizationProviderServiceOuterClass.Verify_Responses> getVerifyMethod;
    if ((getVerifyMethod = AuthorizationProviderServiceGrpc.getVerifyMethod) == null) {
      synchronized (AuthorizationProviderServiceGrpc.class) {
        if ((getVerifyMethod = AuthorizationProviderServiceGrpc.getVerifyMethod) == null) {
          AuthorizationProviderServiceGrpc.getVerifyMethod = getVerifyMethod =
              io.grpc.MethodDescriptor.<sila2.org.silastandard.core.authorizationproviderservice.v1.AuthorizationProviderServiceOuterClass.Verify_Parameters, sila2.org.silastandard.core.authorizationproviderservice.v1.AuthorizationProviderServiceOuterClass.Verify_Responses>newBuilder()
              .setType(io.grpc.MethodDescriptor.MethodType.UNARY)
              .setFullMethodName(generateFullMethodName(SERVICE_NAME, "Verify"))
              .setSampledToLocalTracing(true)
              .setRequestMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  sila2.org.silastandard.core.authorizationproviderservice.v1.AuthorizationProviderServiceOuterClass.Verify_Parameters.getDefaultInstance()))
              .setResponseMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  sila2.org.silastandard.core.authorizationproviderservice.v1.AuthorizationProviderServiceOuterClass.Verify_Responses.getDefaultInstance()))
              .setSchemaDescriptor(new AuthorizationProviderServiceMethodDescriptorSupplier("Verify"))
              .build();
        }
      }
    }
    return getVerifyMethod;
  }

  /**
   * Creates a new async stub that supports all call types for the service
   */
  public static AuthorizationProviderServiceStub newStub(io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<AuthorizationProviderServiceStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<AuthorizationProviderServiceStub>() {
        @java.lang.Override
        public AuthorizationProviderServiceStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new AuthorizationProviderServiceStub(channel, callOptions);
        }
      };
    return AuthorizationProviderServiceStub.newStub(factory, channel);
  }

  /**
   * Creates a new blocking-style stub that supports unary and streaming output calls on the service
   */
  public static AuthorizationProviderServiceBlockingStub newBlockingStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<AuthorizationProviderServiceBlockingStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<AuthorizationProviderServiceBlockingStub>() {
        @java.lang.Override
        public AuthorizationProviderServiceBlockingStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new AuthorizationProviderServiceBlockingStub(channel, callOptions);
        }
      };
    return AuthorizationProviderServiceBlockingStub.newStub(factory, channel);
  }

  /**
   * Creates a new ListenableFuture-style stub that supports unary calls on the service
   */
  public static AuthorizationProviderServiceFutureStub newFutureStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<AuthorizationProviderServiceFutureStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<AuthorizationProviderServiceFutureStub>() {
        @java.lang.Override
        public AuthorizationProviderServiceFutureStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new AuthorizationProviderServiceFutureStub(channel, callOptions);
        }
      };
    return AuthorizationProviderServiceFutureStub.newStub(factory, channel);
  }

  /**
   */
  public static abstract class AuthorizationProviderServiceImplBase implements io.grpc.BindableService {

    /**
     */
    public void verify(sila2.org.silastandard.core.authorizationproviderservice.v1.AuthorizationProviderServiceOuterClass.Verify_Parameters request,
        io.grpc.stub.StreamObserver<sila2.org.silastandard.core.authorizationproviderservice.v1.AuthorizationProviderServiceOuterClass.Verify_Responses> responseObserver) {
      io.grpc.stub.ServerCalls.asyncUnimplementedUnaryCall(getVerifyMethod(), responseObserver);
    }

    @java.lang.Override public final io.grpc.ServerServiceDefinition bindService() {
      return io.grpc.ServerServiceDefinition.builder(getServiceDescriptor())
          .addMethod(
            getVerifyMethod(),
            io.grpc.stub.ServerCalls.asyncUnaryCall(
              new MethodHandlers<
                sila2.org.silastandard.core.authorizationproviderservice.v1.AuthorizationProviderServiceOuterClass.Verify_Parameters,
                sila2.org.silastandard.core.authorizationproviderservice.v1.AuthorizationProviderServiceOuterClass.Verify_Responses>(
                  this, METHODID_VERIFY)))
          .build();
    }
  }

  /**
   */
  public static final class AuthorizationProviderServiceStub extends io.grpc.stub.AbstractAsyncStub<AuthorizationProviderServiceStub> {
    private AuthorizationProviderServiceStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected AuthorizationProviderServiceStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new AuthorizationProviderServiceStub(channel, callOptions);
    }

    /**
     */
    public void verify(sila2.org.silastandard.core.authorizationproviderservice.v1.AuthorizationProviderServiceOuterClass.Verify_Parameters request,
        io.grpc.stub.StreamObserver<sila2.org.silastandard.core.authorizationproviderservice.v1.AuthorizationProviderServiceOuterClass.Verify_Responses> responseObserver) {
      io.grpc.stub.ClientCalls.asyncUnaryCall(
          getChannel().newCall(getVerifyMethod(), getCallOptions()), request, responseObserver);
    }
  }

  /**
   */
  public static final class AuthorizationProviderServiceBlockingStub extends io.grpc.stub.AbstractBlockingStub<AuthorizationProviderServiceBlockingStub> {
    private AuthorizationProviderServiceBlockingStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected AuthorizationProviderServiceBlockingStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new AuthorizationProviderServiceBlockingStub(channel, callOptions);
    }

    /**
     */
    public sila2.org.silastandard.core.authorizationproviderservice.v1.AuthorizationProviderServiceOuterClass.Verify_Responses verify(sila2.org.silastandard.core.authorizationproviderservice.v1.AuthorizationProviderServiceOuterClass.Verify_Parameters request) {
      return io.grpc.stub.ClientCalls.blockingUnaryCall(
          getChannel(), getVerifyMethod(), getCallOptions(), request);
    }
  }

  /**
   */
  public static final class AuthorizationProviderServiceFutureStub extends io.grpc.stub.AbstractFutureStub<AuthorizationProviderServiceFutureStub> {
    private AuthorizationProviderServiceFutureStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected AuthorizationProviderServiceFutureStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new AuthorizationProviderServiceFutureStub(channel, callOptions);
    }

    /**
     */
    public com.google.common.util.concurrent.ListenableFuture<sila2.org.silastandard.core.authorizationproviderservice.v1.AuthorizationProviderServiceOuterClass.Verify_Responses> verify(
        sila2.org.silastandard.core.authorizationproviderservice.v1.AuthorizationProviderServiceOuterClass.Verify_Parameters request) {
      return io.grpc.stub.ClientCalls.futureUnaryCall(
          getChannel().newCall(getVerifyMethod(), getCallOptions()), request);
    }
  }

  private static final int METHODID_VERIFY = 0;

  private static final class MethodHandlers<Req, Resp> implements
      io.grpc.stub.ServerCalls.UnaryMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ServerStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ClientStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.BidiStreamingMethod<Req, Resp> {
    private final AuthorizationProviderServiceImplBase serviceImpl;
    private final int methodId;

    MethodHandlers(AuthorizationProviderServiceImplBase serviceImpl, int methodId) {
      this.serviceImpl = serviceImpl;
      this.methodId = methodId;
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public void invoke(Req request, io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        case METHODID_VERIFY:
          serviceImpl.verify((sila2.org.silastandard.core.authorizationproviderservice.v1.AuthorizationProviderServiceOuterClass.Verify_Parameters) request,
              (io.grpc.stub.StreamObserver<sila2.org.silastandard.core.authorizationproviderservice.v1.AuthorizationProviderServiceOuterClass.Verify_Responses>) responseObserver);
          break;
        default:
          throw new AssertionError();
      }
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public io.grpc.stub.StreamObserver<Req> invoke(
        io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        default:
          throw new AssertionError();
      }
    }
  }

  private static abstract class AuthorizationProviderServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoFileDescriptorSupplier, io.grpc.protobuf.ProtoServiceDescriptorSupplier {
    AuthorizationProviderServiceBaseDescriptorSupplier() {}

    @java.lang.Override
    public com.google.protobuf.Descriptors.FileDescriptor getFileDescriptor() {
      return sila2.org.silastandard.core.authorizationproviderservice.v1.AuthorizationProviderServiceOuterClass.getDescriptor();
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.ServiceDescriptor getServiceDescriptor() {
      return getFileDescriptor().findServiceByName("AuthorizationProviderService");
    }
  }

  private static final class AuthorizationProviderServiceFileDescriptorSupplier
      extends AuthorizationProviderServiceBaseDescriptorSupplier {
    AuthorizationProviderServiceFileDescriptorSupplier() {}
  }

  private static final class AuthorizationProviderServiceMethodDescriptorSupplier
      extends AuthorizationProviderServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoMethodDescriptorSupplier {
    private final String methodName;

    AuthorizationProviderServiceMethodDescriptorSupplier(String methodName) {
      this.methodName = methodName;
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.MethodDescriptor getMethodDescriptor() {
      return getServiceDescriptor().findMethodByName(methodName);
    }
  }

  private static volatile io.grpc.ServiceDescriptor serviceDescriptor;

  public static io.grpc.ServiceDescriptor getServiceDescriptor() {
    io.grpc.ServiceDescriptor result = serviceDescriptor;
    if (result == null) {
      synchronized (AuthorizationProviderServiceGrpc.class) {
        result = serviceDescriptor;
        if (result == null) {
          serviceDescriptor = result = io.grpc.ServiceDescriptor.newBuilder(SERVICE_NAME)
              .setSchemaDescriptor(new AuthorizationProviderServiceFileDescriptorSupplier())
              .addMethod(getVerifyMethod())
              .build();
        }
      }
    }
    return result;
  }
}
